# Generated by roxygen2: do not edit by hand

S3method(coef,betadanish)
S3method(logLik,betadanish)
S3method(plot,bd_aft)
S3method(plot,bd_cure)
S3method(plot,betadanish)
S3method(print,bd_aft)
S3method(print,bd_bayes)
S3method(print,bd_competing)
S3method(print,bd_cure)
S3method(print,betadanish)
S3method(print,betadanish_report)
S3method(print,summary.bd_aft)
S3method(print,summary.bd_competing)
S3method(print,summary.bd_cure)
S3method(print,summary.betadanish)
S3method(summary,bd_aft)
S3method(summary,bd_competing)
S3method(summary,bd_cure)
S3method(summary,betadanish)
S3method(vcov,betadanish)
export(analyze_betadanish)
export(bayes_betadanish)
export(bd_entropy_shannon)
export(bd_order_stat_pdf)
export(cif_betadanish)
export(cif_compare)
export(compare_distributions)
export(compare_models)
export(dbetadanish)
export(fit_bd_aft)
export(fit_bd_competing)
export(fit_bd_cure)
export(fit_betadanish)
export(gof_betadanish)
export(hbetadanish)
export(pbetadanish)
export(qbetadanish)
export(rbetadanish)
export(read_survival_data)
export(report_betadanish)
export(simulate_bd_cure_data)
export(simulate_bd_data)
importFrom(graphics,abline)
importFrom(graphics,grid)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,plot)
importFrom(maxLik,maxLik)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,delete.response)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,model.extract)
importFrom(stats,model.frame)
importFrom(stats,model.response)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,optim)
importFrom(stats,pbeta)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,qbeta)
importFrom(stats,rbeta)
importFrom(stats,rbinom)
importFrom(stats,rexp)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,runif)
importFrom(stats,terms)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(survival,Surv)
importFrom(survival,is.Surv)
importFrom(survival,survfit)
importFrom(utils,head)
importFrom(utils,packageVersion)
importFrom(utils,tail)
