% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{carbon_fibres}
\alias{carbon_fibres}
\title{Breaking Stress of Carbon Fibres}
\format{
A data frame with 100 rows and 2 columns:
\describe{
  \item{time}{Breaking stress in Gba}
  \item{status}{Event indicator (1 = event occurred)}
}
}
\source{
Nichols, M. D., & Padgett, W. J. (2006). A bootstrap control chart for Weibull percentiles. Quality and Reliability Engineering International, 22(2), 141-151.
}
\usage{
carbon_fibres
}
\description{
Breaking stress (in Gba) of 100 carbon fibre specimens. This dataset exhibits
a unimodal (increasing-then-decreasing) hazard pattern that classical
distributions like the Weibull cannot adequately capture.
}
\examples{
data(carbon_fibres)
\donttest{
fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = carbon_fibres)
}
}
\keyword{datasets}
